@@ -5,7 +5,7 @@ from asn1PERser.classes.templates.creator import template_filler
 
 class DefinedType(Type):
     def __init__(self, typereference):
-        super().__init__()
+        super(DefinedType, self).__init__()
         self.typereference = typereference
 
     def fill_template(self):
@@ -32,7 +32,3 @@ class DefinedType(Type):
     @default.setter
     def default(self, default):
         self._default = default
-
-
-    def __repr__(self):
-        return '\t' + super().__repr__() + '\n'
