@@ -3,8 +3,5 @@ from ..type import SimpleType
 
 class RealType(SimpleType):
     def __init__(self):
-        super().__init__()
+        super(RealType, self).__init__()
         self.typereference = "REAL"
-
-    def __repr__(self):
-        return '\t' + super().__repr__() + '\n'
